#
# spec file for package ghc-digest
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name digest
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        0.0.2.1
Release:        1.12
Summary:        CRC32 and Adler32 hashes for bytestrings
License:        BSD-2-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(zlib)
ExcludeArch:    %{ix86}

%description
This package provides efficient hash implementations for strict and lazy
bytestrings. For now, CRC32 and Adler32 are supported; they are implemented as
FFI bindings to efficient code from zlib.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires:       pkgconfig
Requires:       pkgconfig(zlib)
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sat Feb 10 2024 Peter Simons <psimons@suse.com>
- Update digest to version 0.0.2.1.
  [#]# 0.0.2.1 — 10th Febraury 2024
  - Make pkg-config an automatic flag: <https://github.com/TeofilC/digest/pull/21>
* Wed Dec 13 2023 Peter Simons <psimons@suse.com>
- Update digest to version 0.0.2.0.
  [#]# 0.0.2.0 — 13th December 2023
  - Add CRC32C (Thanks to @4eUep): <https://github.com/TeofilC/digest/pull/18>
  - Support latest GHC versions: <https://github.com/TeofilC/digest/pull/19>
* Sun Sep  3 2023 Peter Simons <psimons@suse.com>
- Update digest to version 0.0.1.7 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Mar 12 2023 Peter Simons <psimons@suse.com>
- Update digest to version 0.0.1.7.
  [#]# 0.0.1.7 — 5th March 2023
  - Don't use 'pkg-config' to locate zlib on FreeBSD (Thanks to @arrowd): <https://github.com/TeofilC/digest/pull/13>
* Sun Mar  5 2023 Peter Simons <psimons@suse.com>
- Update digest to version 0.0.1.6.
  [#]# 0.0.1.6 — 5th March 2023
  - Introduce 'pkg-config' cabal flag (Thanks to @jonathanlking): <https://github.com/TeofilC/digest/pull/11>
* Tue Jan 24 2023 Peter Simons <psimons@suse.com>
- Update digest to version 0.0.1.5.
  Upstream added a new change log file in this release. With no
  previous version to compare against, the automatic updater cannot
  reliable determine the relevante entries for this release.
* Wed Jan 11 2023 Peter Simons <psimons@suse.com>
- Update digest to version 0.0.1.4 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Dec 12 2022 Peter Simons <psimons@suse.com>
- Update digest to version 0.0.1.4.
  Upstream does not provide a change log file.
* Sat Jul 10 2021 psimons@suse.com
- Update digest to version 0.0.1.3.
  Upstream does not provide a change log file.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Wed May 16 2018 psimons@suse.com
- Prefer the new %%license attribute over %%doc.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.0.1.2 revision 0 with cabal2obs.
* Wed Mar 26 2014 peter.trommler@ohm-hochschule.de
- fix license tag
* Mon May 13 2013 peter.trommler@ohm-hochschule.de
- update to 0.0.1.2 from upstream (no changelog)
  * minor change in cabal flag default
* Wed Oct  3 2012 peter.trommler@ohm-hochschule.de
- update to 0.0.1.1 from upstream (no changelog)
* Thu Jun  7 2012 peter.trommler@ohm-hochschule.de
- cabal2spec 0.25.5 spec file template
* Wed Jan 18 2012 herbert@graeber-clan.de
- initial packaging for Fedora automatically generated by cabal2spec-0.24.1
